START_REPLACE = """<!DOCTYPE html>
<html lang="de-de">
    <head>
        <meta charset="UTF-8"/>
        <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
        <meta name="announcement" content="This is a PyWSGIRef generated page."/>
        """

END_REPLACE = """
        <p style="font-size: 7px; text-align: center;">Generated by PyWSGIRef</p>
    </body>
</html>"""

MODERN_STYLING = """<link rel='stylesheet' href='https://leanderkafemann.github.io/PyWSGIRef-Backend/styling/modernStyling.css'/>"""